pub fn init_on_addr(addr: &str)
Inits Logger on given addr and sets it as the logger for log
13fn main() { 14 init_on_addr("127.0.0.1:8080"); 15 log::info!("The logger seems to work"); 16 std::thread::sleep(Duration::from_secs(1)); // If the main thread finishes before the logs 17 // are sent the logs cannot be delivered 18}